@@ -24,6 +24,7 @@
   2005/22/05 - APPLE test for limits.h included by Aaron Harwood
   2007/08/10 - strncpy used instead of strcpy - nm
   2007/12/24 - change `c' variable type - NIDE, Naoyuki
+  2020/12/24 - Add a warning for btrfs (no inode usage)
 
 */
 
@@ -163,6 +164,11 @@ int check_dir (char *dir, char *path, int linkcount, int norecurse)
       goto abort;
     }
     linkcount = statinfo.st_nlink;
+    if (linkcount == 1) 
+    {
+       fprintf(stderr, "WARNIING: It seems you are using BTRFS, if this is true chkdirs can't help you to find hidden files/dirs\n"); 
+       goto abort; 
+     } 
   }
 
   if (!(dirhandle = opendir("."))) {
